@@ -2,6 +2,7 @@ BEGIN TRANSACTION;
 
 DROP TABLE IF EXISTS test1;
 DROP TABLE IF EXISTS test2;
+DROP TABLE IF EXISTS test3;
 
 CREATE TABLE test1 (
     id INTEGER PRIMARY KEY AUTOINCREMENT,
@@ -15,4 +16,9 @@ CREATE TABLE test2 (
     description TEXT 
 );
 
+CREATE TABLE test3 (
+    id INTEGER PRIMARY KEY,
+    name TEXT NOT NULL
+);
+
 COMMIT;
